@@ -17,6 +17,7 @@ const PasteManager = imports.pasteManager;
 const MAX_NICK_UPDATE_TIME = 5; /* s */
 const MAX_LINES = 5;
 
+let _checker = null;
 
 const ChatEntry = new Lang.Class({
     Name: 'ChatEntry',
@@ -35,8 +36,14 @@ const ChatEntry = new Lang.Class({
 
         PasteManager.DropTargetIface.addTargets(this, this);
 
+        if (!_checker)
+            _checker = new Gspell.Checker();
+
+        let buffer = Gspell.EntryBuffer.get_from_gtk_entry_buffer(this.buffer);
+        buffer.set_spell_checker (_checker);
+
         let spellEntry = Gspell.Entry.get_from_gtk_entry(this);
-        spellEntry.basic_setup();
+        spellEntry.set_inline_spell_checking(true);
 
         this._useDefaultHandler = false;
     },
@@ -221,6 +228,9 @@ const EntryArea = new Lang.Class({
         this._membersChangedId =
             this._room.connect('members-changed',
                                Lang.bind(this, this._updateCompletions));
+        this._nicknameChangedId =
+            this._room.account.connect('notify::nickname',
+                                       Lang.bind(this, this._updateNick));
         this._channelChangedId =
             this._room.connect('notify::channel',
                                Lang.bind(this, this._onChannelChanged));
@@ -379,11 +389,11 @@ const EntryArea = new Lang.Class({
         this._updateCompletions();
 
         if (room.channel)
-            this._nicknameChangedId =
+            this._selfAliasChangedId =
                 room.channel.connection.connect('notify::self-contact',
                                                 Lang.bind(this, this._updateNick));
         else
-            this._nicknameChangedId = 0;
+            this._selfAliasChangedId = 0;
         this._updateNick();
     },
 
@@ -436,8 +446,11 @@ const EntryArea = new Lang.Class({
         if (this._membersChangedId)
             this._room.disconnect(this._membersChangedId);
         this._membersChangedId = 0;
+        if (this._selfAliasChangedId)
+            this._room.channel.connection.disconnect(this._selfAliasChangedId);
+        this._selfAliasChangedId = 0;
         if (this._nicknameChangedId)
-            this._room.channel.connection.disconnect(this._nicknameChangedId);
+            this._room.account.disconnect(this._nicknameChangedId);
         this._nicknameChangedId = 0;
         if (this._channelChangedId)
             this._room.disconnect(this._channelChangedId);
